@@ -48,7 +48,7 @@ gsh_check_row()
 }
 
 void
-gsh_handle_arguments(int argc, char **argv)
+gsh_parse_arguments(int argc, char **argv)
 {
  unsigned int    counter;
 
@@ -56,7 +56,7 @@ gsh_handle_arguments(int argc, char **argv)
  {
   if (argv[counter][0] == '-')
   {
-   gsh_handle_options(argc, argv, &counter);
+   gsh_handle_switch_arguments(argc, argv, &counter);
   }
   else
   {
@@ -64,3 +64,4 @@ gsh_handle_arguments(int argc, char **argv)
   }
  }
 }
+
