@@ -23,5 +23,5 @@
 #define GSH_ARGUMENTS_H
 
 void
-                gsh_handle_arguments(int argc, char **argv);
+gsh_parse_arguments(int argc, char **argv);
 #endif
