@@ -25,27 +25,6 @@
 extern unsigned int gsh_rows;
 extern unsigned int gsh_row;
 
-void
-gsh_command_button(char *command)
-{
- char           *label_text;
- label_text = antiright_beautified_label(command);
- gsh_button = gtk_button_new_with_label(label_text);
- free(label_text);
- g_signal_connect(G_OBJECT(gsh_button), "clicked",
-		  G_CALLBACK(system_cb), command);
- gsh_manage(gsh_button);
-}
-
-void
-gsh_image_button(char *command, char *filename)
-{
-	GtkWidget *image;
-	image=gtk_image_new_from_file(filename);
-	gsh_command_button(command);
-	gtk_button_set_image(GTK_BUTTON(gsh_button), image);
-}
-
 void
 gsh_manage(GtkWidget *widget)
 {
