@@ -33,6 +33,11 @@
 #include "label.h"
 #include "button.h"
 #include "text.h"
+#include "updated_label.h"
+#include "updated_progress.h"
+#include "option_options.h"
+#include "updated_options.h"
+#include "add_options.h"
 
 GtkWidget      *gsh_window;
 GtkWidget      *gsh_hbox;
