@@ -22,7 +22,7 @@
 
 #include "gtkshell.h"
 
-void
+GtkWidget*
 gsh_setup_command_entry(char *command)
 {
  GtkWidget      *entry;
@@ -31,6 +31,16 @@ gsh_setup_command_entry(char *command)
  g_signal_connect(G_OBJECT(entry), "activate", G_CALLBACK(entry_cb),
 		  (gpointer) command);
  gsh_manage(entry);
+ return(entry);
+}
+
+void
+gsh_setup_prompt_command_entry(char *command)
+{
+	GtkWidget *entry;
+	entry=gsh_setup_command_entry(command);
+	g_signal_connect(G_OBJECT(entry), "activate", 
+		G_CALLBACK(gtk_main_quit), (gpointer) command);
 }
 
 void
