@@ -23,9 +23,12 @@
 #ifndef GSH_TEXT_H
 #define GSH_TEXT_H
 
-void
+GtkWidget*
 gsh_setup_command_entry(char *command);
 
+void
+gsh_setup_prompt_command_entry(char *command);
+
 void
 gsh_text_area();
 
